@@ -15,9 +15,9 @@ def detect_init(*args, **kwargs):
     """
     detected_os = platform.system()
     if detected_os == 'Linux':
-        supported_linux_flavors = ['Ubuntu', 'debian']
+        supported_linux_flavors = ['ubuntu', 'debian']
         flavor = platform.linux_distribution()[0]
-        if flavor not in supported_linux_flavors:
+        if flavor.lower() not in supported_linux_flavors:
             log.warn('{0} is not a support Linux distribution'.format(flavor))
         return detect_linux_init(*args, **kwargs)
     else:
