@@ -5,11 +5,11 @@ import os
 
 from nose.plugins.skip import SkipTest
 
-from monagent.common.aggregator import MetricsAggregator
-from monagent.monstatsd import Server
-from monagent.common.util import PidFile
-from monagent.common.config import get_logging_config
-from monagent.collector.jmxfetch import JMXFetch
+from monasca_agent.common.aggregator import MetricsAggregator
+from monasca_agent.statsd import Server
+from monasca_agent.common.util import PidFile
+from monasca_agent.common.config import get_logging_config
+from monasca_agent.collector.jmxfetch import JMXFetch
 
 
 STATSD_PORT = 8127
